"use client";
import React from 'react';
import { Box, Button, Divider, Flex, Group, Image, Text } from '@mantine/core';
import { IconBook, IconCurrencyRupee, IconHome, IconLogout, IconPhoneFilled, IconSettings } from '@tabler/icons-react';
import Link from 'next/link';
import { useRouter } from "next/navigation";
import { Providers } from '../providers';
import logo from '@/app/image/logo.jpg';
import NextImage from 'next/image';

export default function RootLayout({ children }: { children: React.ReactNode }) {
    const router = useRouter();

    async function handleLogout(e: React.FormEvent) {
        e.preventDefault();
        localStorage.removeItem("access_token");
        router.push("/login")
    }
    return (
        <html lang="en">
            <body>
                <Providers>
                    <div style={{ backgroundColor: "#e6ffff", width: "100%", height: '100%' }}>
                        {/* Image -Logo */}
                        <Box style={{
                            position: 'relative', width: '100%', height: '11%',
                            display: "flex",
                            justifyContent: "flex-start",
                            background: "linear-gradient(15deg,rgba(2, 163, 85, 1) 55%, rgba(101, 101, 184, 1) 100%)",
                        }}>
                            <Image
                                // radius="md"
                                fit="cover"
                                src={logo}
                                component={NextImage}
                                alt="ebanking"
                                style={{ width: "100%", height: "100%" }}
                            />
                            <Text
                                style={{
                                    position: 'absolute',
                                    top: '60%',
                                    left: '80%',
                                    color: 'white',
                                    textShadow: '1px 1px 2px black',
                                }}
                            >
                                <IconPhoneFilled size={20} />
                                Toll Free No : 1800-180-8008
                            </Text>
                        </Box>
                        <div
                            style={{
                                flex: 1,
                                display: "flex",
                                alignItems: "left",
                                justifyContent: "right",
                            }}>
                            <Group mt="md" gap="sm">
                                <Link href="/">
                                    <Button leftSection={<IconHome />} variant="light" color="blue">Home</Button>
                                </Link>
                                <Link href="/accounts">
                                    <Button leftSection={<IconBook />} variant="subtle">Accounts</Button>
                                </Link>
                                <Link href="/FundsTransfer">
                                    <Button leftSection={<IconCurrencyRupee />} variant="subtle">Send Money</Button>
                                </Link>
                                <Link href="/settings">
                                    <Button leftSection={<IconSettings />} variant="subtle">Settings</Button>
                                </Link>

                                <Button leftSection={<IconLogout />} variant="subtle" onClick={handleLogout}>Logout</Button>

                            </Group>
                        </div>
                        <Divider size="xs" color ='blue' />
                        <div>{children}</div>
                        <Divider size="xs" color ='blue' />
                        {/* Footer */}
                        <Flex justify="center" align="center">
                            <Text c="dimmed" size="xs">© 2025 Kangra Central Co- Operative Bank</Text>
                        </Flex>
                    </div>
                </Providers>
            </body>
        </html>
    );
}
